@@ -19,11 +19,12 @@ from PyQt5.QtWebKitWidgets import QWebView, QWebPage
 
 from calibre.ebooks.chardet import xml_to_unicode
 from calibre import xml_replace_entities, prepare_string_for_xml
-from calibre.gui2 import open_url, error_dialog, choose_files
+from calibre.gui2 import open_url, error_dialog, choose_files, gprefs, NO_URL_FORMATTING, secure_web_page
 from calibre.utils.soupparser import fromstring
 from calibre.utils.config import tweaks
 from calibre.utils.imghdr import what
 
+
 class PageAction(QAction):  # {{{
 
     def __init__(self, wac, icon, text, checkable, view):
@@ -53,6 +54,7 @@ class PageAction(QAction):  # {{{
 
 # }}}
 
+
 class BlockStyleAction(QAction):  # {{{
 
     def __init__(self, text, name, view):
@@ -65,6 +67,7 @@ class BlockStyleAction(QAction):  # {{{
 
 # }}}
 
+
 class EditorWidget(QWebView):  # {{{
 
     def __init__(self, parent=None):
@@ -107,7 +110,7 @@ class EditorWidget(QWebView):  # {{{
                     _('Align justified'), False),
                 ('Undo', 'undo', 'edit-undo', _('Undo'), False),
                 ('Redo', 'redo', 'edit-redo', _('Redo'), False),
-                ('RemoveFormat', 'remove_format', 'trash', _('Remove formatting'), False),
+                ('RemoveFormat', 'remove_format', 'edit-clear', _('Remove formatting'), False),
                 ('Copy', 'copy', 'edit-copy', _('Copy'), False),
                 ('Paste', 'paste', 'edit-paste', _('Paste'), False),
                 ('Cut', 'cut', 'edit-cut', _('Cut'), False),
@@ -163,11 +166,12 @@ class EditorWidget(QWebView):  # {{{
         self.action_insert_link.triggered.connect(self.insert_link)
         self.pageAction(QWebPage.ToggleBold).changed.connect(self.update_link_action)
         self.action_insert_link.setEnabled(False)
-        self.action_clear = QAction(QIcon(I('edit-clear.png')), _('Clear'), self)
+        self.action_clear = QAction(QIcon(I('trash.png')), _('Clear'), self)
         self.action_clear.triggered.connect(self.clear_text)
 
         self.page().setLinkDelegationPolicy(QWebPage.DelegateAllLinks)
         self.page().linkClicked.connect(self.link_clicked)
+        secure_web_page(self.page().settings())
 
         self.setHtml('')
         self.set_readonly(False)
@@ -211,7 +215,7 @@ class EditorWidget(QWebView):  # {{{
             return
         url = self.parse_link(link)
         if url.isValid():
-            url = unicode(url.toString(QUrl.None))
+            url = unicode(url.toString(NO_URL_FORMATTING))
             self.setFocus(Qt.OtherFocusReason)
             if is_image:
                 self.exec_command('insertHTML',
@@ -239,6 +243,7 @@ class EditorWidget(QWebView):  # {{{
         d.bb = QDialogButtonBox(QDialogButtonBox.Ok|QDialogButtonBox.Cancel)
         d.br = b = QPushButton(_('&Browse'))
         b.setIcon(QIcon(I('document_open.png')))
+
         def cf():
             files = choose_files(d, 'select link file', _('Choose file'), select_only_single_file=True)
             if files:
@@ -402,13 +407,14 @@ class EditorWidget(QWebView):  # {{{
         parent = self._parent()
         if hasattr(parent, 'toolbars_visible'):
             vis = parent.toolbars_visible
-            menu.addAction(_('%s toolbars') % (_('Hide') if vis else _('Show')),
-                           (parent.hide_toolbars if vis else parent.show_toolbars))
+            menu.addAction(_('%s toolbars') % (_('Hide') if vis else _('Show')), parent.toggle_toolbars)
         menu.exec_(ev.globalPos())
 
 # }}}
 
 # Highlighter {{{
+
+
 State_Text = -1
 State_DocType = 0
 State_Comment = 1
@@ -420,6 +426,7 @@ State_SingleQuote = 6
 State_DoubleQuote = 7
 State_AttributeValue = 8
 
+
 class Highlighter(QSyntaxHighlighter):
 
     def __init__(self, doc):
@@ -619,10 +626,14 @@ class Highlighter(QSyntaxHighlighter):
 
 # }}}
 
+
 class Editor(QWidget):  # {{{
 
-    def __init__(self, parent=None, one_line_toolbar=False):
+    toolbar_prefs_name = None
+
+    def __init__(self, parent=None, one_line_toolbar=False, toolbar_prefs_name=None):
         QWidget.__init__(self, parent)
+        self.toolbar_prefs_name = toolbar_prefs_name or self.toolbar_prefs_name
         self.toolbar1 = QToolBar(self)
         self.toolbar2 = QToolBar(self)
         self.toolbar3 = QToolBar(self)
@@ -657,6 +668,10 @@ class Editor(QWidget):  # {{{
         self.tabs.currentChanged[int].connect(self.change_tab)
         self.highlighter = Highlighter(self.code_edit.document())
         self.layout().setContentsMargins(0, 0, 0, 0)
+        if self.toolbar_prefs_name is not None:
+            hidden = gprefs.get(self.toolbar_prefs_name)
+            if hidden:
+                self.hide_toolbars()
 
         # toolbar1 {{{
         self.toolbar1.addAction(self.editor.action_undo)
@@ -713,6 +728,7 @@ class Editor(QWidget):  # {{{
     def html(self):
         def fset(self, v):
             self.editor.html = v
+
         def fget(self):
             self.tabs.setCurrentIndex(0)
             return self.editor.html
@@ -734,6 +750,7 @@ class Editor(QWidget):  # {{{
     def tab(self):
         def fget(self):
             return 'code' if self.tabs.currentWidget() is self.code_edit else 'wyswyg'
+
         def fset(self, val):
             self.tabs.setCurrentWidget(self.code_edit if val == 'code' else self.wyswyg)
         return property(fget=fget, fset=fset)
@@ -754,10 +771,17 @@ class Editor(QWidget):  # {{{
         self.toolbar2.setVisible(True)
         self.toolbar3.setVisible(True)
 
+    def toggle_toolbars(self):
+        visible = self.toolbars_visible
+        getattr(self, ('hide' if visible else 'show') + '_toolbars')()
+        if self.toolbar_prefs_name is not None:
+            gprefs.set(self.toolbar_prefs_name, visible)
+
     @dynamic_property
     def toolbars_visible(self):
         def fget(self):
             return self.toolbar1.isVisible() or self.toolbar2.isVisible() or self.toolbar3.isVisible()
+
         def fset(self, val):
             getattr(self, ('show' if val else 'hide') + '_toolbars')()
         return property(fget=fget, fset=fset)
@@ -770,6 +794,7 @@ class Editor(QWidget):  # {{{
 
 # }}}
 
+
 if __name__ == '__main__':
     app = QApplication([])
     w = Editor()
@@ -779,5 +804,3 @@ if __name__ == '__main__':
     set out to have an <em>affair</em>, <span style="font-style:italic; background-color:red">much</span> less a long-term, devoted one.</span>'''
     app.exec_()
     # print w.html
-
-
