@@ -14,10 +14,12 @@ from calibre.ebooks.css_transform_rules import (
     validate_rule, safe_parser, compile_rules, transform_sheet, ACTION_MAP, MATCH_TYPE_MAP, export_rules, import_rules)
 from calibre.gui2 import error_dialog, elided_text, choose_save_file, choose_files
 from calibre.gui2.tag_mapper import (
-    RuleEditDialog as RuleEditDialogBase, Rules as RulesBase, RulesDialog as
-    RulesDialogBase, RuleItem as RuleItemBase, SaveLoadMixin)
+    RuleEdit as RE, RuleEditDialog as RuleEditDialogBase, Rules as RulesBase,
+    RulesDialog as RulesDialogBase, RuleItem as RuleItemBase, SaveLoadMixin)
 from calibre.gui2.widgets2 import Dialog
 from calibre.utils.config import JSONConfig
+from calibre.utils.localization import localize_user_manual_link
+
 
 class RuleEdit(QWidget):  # {{{
 
@@ -76,6 +78,13 @@ class RuleEdit(QWidget):  # {{{
             if clause is not parts[-1]:
                 h.addWidget(QLabel('\xa0'))
 
+        self.regex_help = la = QLabel('<p>' + RE.REGEXP_HELP_TEXT % localize_user_manual_link(
+        'https://manual.calibre-ebook.com/regexp.html'))
+        la.setOpenExternalLinks(True)
+        la.setWordWrap(True)
+        l.addWidget(la)
+        l.addStretch(10)
+
         self.update_state()
 
     def sizeHint(self):
@@ -93,7 +102,7 @@ class RuleEdit(QWidget):  # {{{
         if 'matches' in mt:
             tt = _('A regular expression')
         elif mt in '< > <= >='.split():
-            tt = _('Either a CSS length, such as 10pt or a unit less number. If a unitless'
+            tt = _('Either a CSS length, such as 10pt or a unit less number. If a unit less'
                    ' number is used it will be compared with the CSS value using whatever unit'
                    ' the value has. Note that comparison automatically converts units, except'
                    ' for relative units like percentage or em, for which comparison fails'
@@ -108,6 +117,7 @@ class RuleEdit(QWidget):  # {{{
         elif ac in '+=*/':
             tt = _('A number')
         self.action_data.setToolTip(tt)
+        self.regex_help.setVisible('matches' in mt)
 
     @property
     def rule(self):
@@ -142,6 +152,7 @@ class RuleEdit(QWidget):  # {{{
         return True
 # }}}
 
+
 class RuleEditDialog(RuleEditDialogBase):  # {{{
 
     PREFS_NAME = 'edit-css-transform-rule'
@@ -149,6 +160,7 @@ class RuleEditDialog(RuleEditDialogBase):  # {{{
     RuleEditClass = RuleEdit
 # }}}
 
+
 class RuleItem(RuleItemBase):  # {{{
 
     @staticmethod
@@ -169,6 +181,7 @@ class RuleItem(RuleItemBase):  # {{{
         return text
 # }}}
 
+
 class Rules(RulesBase):  # {{{
 
     RuleItemClass = RuleItem
@@ -178,6 +191,7 @@ class Rules(RulesBase):  # {{{
             ' below to get started.')
 # }}}
 
+
 class Tester(Dialog):  # {{{
 
     DIALOG_TITLE = _('Test style transform rules')
@@ -224,6 +238,7 @@ class Tester(Dialog):  # {{{
         return QSize(800, 600)
 # }}}
 
+
 class RulesDialog(RulesDialogBase):  # {{{
 
     DIALOG_TITLE = _('Edit style transform rules')
@@ -238,6 +253,7 @@ class RulesDialog(RulesDialogBase):  # {{{
         RulesDialogBase.__init__(self, *args, **kw)
 # }}}
 
+
 class RulesWidget(QWidget, SaveLoadMixin):  # {{{
 
     changed = pyqtSignal()
