@@ -22,9 +22,11 @@ from calibre.utils.config import prefs, dynamic
 if iswindows:
     winutil = plugins['winutil'][0]
 
+
 class AbortInit(Exception):
     pass
 
+
 def option_parser():
     parser = _option_parser(_('''\
 %prog [options] [path_to_ebook]
@@ -51,6 +53,7 @@ path_to_ebook to the database.
     setup_gui_option_parser(parser)
     return parser
 
+
 def find_portable_library():
     base = get_portable_base()
     if base is None:
@@ -84,6 +87,7 @@ def find_portable_library():
     if not os.path.exists(lib):
         os.mkdir(lib)
 
+
 def init_qt(args):
     parser = option_parser()
     opts, args = parser.parse_args(args)
@@ -98,7 +102,15 @@ def init_qt(args):
     override = 'calibre-gui' if islinux else None
     app = Application(args, override_program_name=override)
     app.file_event_hook = EventAccumulator()
-    app.setWindowIcon(QIcon(I('library.png', allow_user_override=False)))
+    try:
+        from PyQt5.Qt import QX11Info
+        is_x11 = QX11Info.isPlatformX11()
+    except Exception:
+        is_x11 = False
+    # Ancient broken VNC servers cannot handle icons of size greater than 256
+    # https://www.mobileread.com/forums/showthread.php?t=278447
+    ic = 'lt.png' if is_x11 else 'library.png'
+    app.setWindowIcon(QIcon(I(ic, allow_user_override=False)))
     return app, opts, args
 
 
@@ -147,10 +159,35 @@ def get_library_path(gui_runner):
             library_path = gui_runner.choose_dir(get_default_library_path())
     return library_path
 
+
 def repair_library(library_path):
     from calibre.gui2.dialogs.restore_library import repair_library_at
     return repair_library_at(library_path)
 
+
+def windows_repair(library_path=None):
+    from binascii import hexlify, unhexlify
+    import cPickle, subprocess
+    if library_path:
+        library_path = hexlify(cPickle.dumps(library_path, -1))
+        winutil.prepare_for_restart()
+        os.environ['CALIBRE_REPAIR_CORRUPTED_DB'] = library_path
+        subprocess.Popen([sys.executable])
+    else:
+        try:
+            app = Application([])
+            from calibre.gui2.dialogs.restore_library import repair_library_at
+            library_path = cPickle.loads(unhexlify(os.environ.pop('CALIBRE_REPAIR_CORRUPTED_DB')))
+            done = repair_library_at(library_path, wait_time=4)
+        except Exception:
+            done = False
+            error_dialog(None, _('Failed to repair library'), _(
+                'Could not repair library. Click "Show details" for more information.'), det_msg=traceback.format_exc(), show=True)
+        if done:
+            subprocess.Popen([sys.executable])
+        app.quit()
+
+
 class EventAccumulator(object):
 
     def __init__(self):
@@ -159,6 +196,7 @@ class EventAccumulator(object):
     def __call__(self, ev):
         self.events.append(ev)
 
+
 class GuiRunner(QObject):
     '''Make sure an event loop is running before starting the main work of
     initialization'''
@@ -266,6 +304,13 @@ class GuiRunner(QObject):
                         det_msg=traceback.format_exc()
                         )
             if repair:
+                if iswindows:
+                    # On some windows systems the existing db file gets locked
+                    # by something when running restore from the main process.
+                    # So run the restore in a separate process.
+                    windows_repair(self.library_path)
+                    self.app.quit()
+                    return
                 if repair_library(self.library_path):
                     db = LibraryDatabase(self.library_path)
         except:
@@ -295,6 +340,7 @@ class GuiRunner(QObject):
 
         self.initialize_db()
 
+
 def get_debug_executable():
     e = sys.executable if getattr(sys, 'frozen', False) else sys.argv[0]
     if hasattr(sys, 'frameworks_dir'):
@@ -312,6 +358,7 @@ def get_debug_executable():
             exe = base + '-debug' + ext
     return exe
 
+
 def run_in_debug_mode(logpath=None):
     import tempfile, subprocess
     fd, logpath = tempfile.mkstemp('.txt')
@@ -327,9 +374,11 @@ def run_in_debug_mode(logpath=None):
             stderr=subprocess.STDOUT, stdin=open(os.devnull, 'r'),
             creationflags=creationflags)
 
+
 def shellquote(s):
     return "'" + s.replace("'", "'\\''") + "'"
 
+
 def run_gui(opts, args, listener, app, gui_debug=None):
     initialize_file_icon_provider()
     app.load_builtin_fonts(scan_for_fonts=True)
@@ -383,8 +432,10 @@ def run_gui(opts, args, listener, app, gui_debug=None):
         open_local_file(debugfile)
     return ret
 
+
 singleinstance_name = 'calibre_GUI'
 
+
 def cant_start(msg=_('If you are sure it is not running')+', ',
                det_msg=_('Timed out waiting for response from running calibre'),
                listener_failed=False):
@@ -410,6 +461,7 @@ def cant_start(msg=_('If you are sure it is not running')+', ',
 
     raise SystemExit(1)
 
+
 def build_pipe(print_error=True):
     t = RC(print_error=print_error)
     t.start()
@@ -419,6 +471,7 @@ def build_pipe(print_error=True):
         raise SystemExit(1)
     return t
 
+
 def shutdown_other(rc=None):
     if rc is None:
         rc = build_pipe(print_error=False)
@@ -435,6 +488,7 @@ def shutdown_other(rc=None):
     prints(_('Failed to shutdown running calibre instance'))
     raise SystemExit(1)
 
+
 def communicate(opts, args):
     t = build_pipe()
     if opts.shutdown_running_calibre:
@@ -447,6 +501,7 @@ def communicate(opts, args):
     t.conn.close()
     raise SystemExit(0)
 
+
 def create_listener():
     if islinux:
         from calibre.utils.ipc.server import LinuxListener as Listener
@@ -454,7 +509,11 @@ def create_listener():
         from multiprocessing.connection import Listener
     return Listener(address=gui_socket_address())
 
+
 def main(args=sys.argv):
+    if iswindows and 'CALIBRE_REPAIR_CORRUPTED_DB' in os.environ:
+        windows_repair()
+        return 0
     gui_debug = None
     if args[0] == '__CALIBRE_GUI_DEBUG__':
         gui_debug = args[1]
@@ -534,5 +593,3 @@ if __name__ == '__main__':
                 '%s<b>Log:</b><br>%s')%(unicode(err),
                     unicode(tb).replace('\n', '<br>'),
                     log.replace('\n', '<br>')))
-
-
